#!/bin/bash

set -e

WORK_DIR="offline_installer_tmp"
PKG_DIR="$WORK_DIR/offline_packages"
QDD_URL="https://files.lrtimelapse.com/dslrdashboard/V3.6.4/qDslrDashboard_V3.6.4_RPI4_Buster.tar.gz"
QDD_FILE="qDslrDashboard_V3.6.4_RPI4_Buster.tar.gz"

# Make sure apt-rdepends is installed
sudo apt-get install -y apt-rdepends

rm -rf "$WORK_DIR"
mkdir -p "$PKG_DIR"
cd "$PKG_DIR"

PACKAGES=(
  libraw20
  libexiv2-27
  libusb-1.0-0
  libqt5serialport5
  libqt5svg5
  libqt5network5
  libqt5gui5
  libqt5widgets5
  libqt5core5a
  libxcb-keysyms1
  libxcb-image0
  libxcb-shm0
  libxcb-icccm4
  libxcb-sync1
  libxcb-xfixes0
  libxcb-shape0
  libxcb-randr0
  libxcb-render-util0
  libxcb-xinput0
  unzip
  wget
  libopencv-features2d-dev
  libopencv-core-dev
  libopencv-imgproc-dev
  libopencv-highgui-dev
  libqt5bluetooth5
  qml-module-qtmultimedia
  libqt5multimedia5
  libqt5multimediawidgets5
  libqt5multimedia5-plugins
  hostapd
  dnsmasq
)

for pkg in "${PACKAGES[@]}"; do
  apt-rdepends "$pkg" 2>/dev/null | grep -v '^ ' | while read dep; do
    if apt-cache show "$dep" &>/dev/null; then
      if ! ls "$dep"_*.deb &>/dev/null; then
        apt download "$dep" || echo "Failed to download $dep"
      fi
    fi
  done
done

cd ../

wget -N "$QDD_URL"

cd ../

cp -v install.sh "$WORK_DIR"/ || echo "install.sh not found – skipped"
cp -v Readme.txt "$WORK_DIR"/ || echo "Readme.txt not found – skipped"
cp -v qmlmodelslib.tar.gz "$WORK_DIR"/ || echo "qmlmodelslib.tar.gz not found – skipped"
cp -v getOfflinePackage.sh "$WORK_DIR"/ || echo "qmlmodelslib.tar.gz not found – skipped"

tar -czf offline_installer.tar.gz -C "$WORK_DIR" .

echo "done"
